@@ -38,6 +38,8 @@
 #include <QtConcurrent/QtConcurrent>
 
 #include <qpa/qplatformintegrationfactory_p.h>
+#include <private/qapplication_p.h>
+#include <private/qcoreapplication_p.h>
 #include <private/qwidget_p.h>
 
 #include <DStandardPaths>
@@ -327,8 +329,8 @@ void DApplicationPrivate::_q_onNewInstanceStarted()
 
     for (QWidget *window : qApp->topLevelWidgets()) {
         if (qobject_cast<DMainWindow*>(window)) {
-            // 如果窗口最小化，應當先將其show出來
-            if (window->isMinimized())
+            // 如果窗口最小化或者隐藏了，應當先將其show出來
+            if (window->isMinimized() || window->isHidden())
                 window->showNormal();
 
             window->activateWindow();
@@ -420,6 +422,75 @@ bool DApplicationPrivate::isUserManualExists()
  * \~chinese \param argc 作用同 QApplication::QApplication 参数 argc。
  * \~chinese \param argv 作用同 QApplication::QApplication 参数 argv。
  */
+
+/*!
+ * \~chinese \brief DApplication::globalApplication 返回一个DApplicatioin实例
+ * \~chinese 如果在执行此函数之前DApplication已经被创建则返回已存在的实例，否则直接创建一个
+ * \~chinese 新的DApplication实例并返回。主要用于与deepin-trubo服务相配合，用于共享
+ * \~chinese deepin-turbo dtkwidget booster中已经创建的DApplication对象，以此节省初始化时间。
+ * \~chinese \param argc 传递给DApplication的构造函数
+ * \~chinese \param argv 传递给DApplication的构造函数
+ * \~chinese \return 返回一个DApplication对象
+ * \~chinese \warning 不保证获取的DApplication对象一定有效，如果实例已存在，则直接使
+ * \~chinese 用static_case将其转换为DApplication对象
+ */
+DApplication *DApplication::globalApplication(int &argc, char **argv)
+{
+    if (instance()) {
+        auto dp = static_cast<QCoreApplicationPrivate*>(qApp->QCoreApplication::d_ptr.data());
+        Q_ASSERT(dp);
+
+        // 清理QGuiApplication库的命令行参数
+        int j = argc ? 1 : 0;
+        const QByteArrayList qt_command = {
+            "-platformpluginpath",
+            "-platform",
+            "-platformtheme",
+            "-qwindowgeometry",
+            "-geometry",
+            "-qwindowtitle",
+            "-title",
+            "-qwindowicon",
+            "-icon",
+            "-plugin",
+            "-reverse",
+            "-session",
+            "-style"
+        };
+        for (int i = 1; i < argc; i++) {
+            if (!argv[i])
+                continue;
+            if (*argv[i] != '-') {
+                argv[j++] = argv[i];
+                continue;
+            }
+            const char *arg = argv[i];
+            if (arg[1] == '-') // startsWith("--")
+                ++arg;
+            if (qt_command.indexOf(arg) >= 0) {
+                // 跳过这个参数的值
+                ++i;
+            } else if (strcmp(arg, "-testability") != 0
+                       && strncmp(arg, "-style=", 7) != 0) {
+                argv[j++] = argv[i];
+            }
+        }
+
+        if (j < argc) {
+            argv[j] = nullptr;
+            argc = j;
+        }
+
+        dp->argc = argc;
+        dp->argv = argv;
+        dp->processCommandLineArguments();
+        static_cast<QApplicationPrivate*>(dp)->process_cmdline();
+        return qApp;
+    }
+
+    return new DApplication(argc, argv);
+}
+
 DApplication::DApplication(int &argc, char **argv) :
     QApplication(argc, argv),
     DObject(*new DApplicationPrivate(this))
