@@ -69,10 +69,12 @@ void DDialogPrivate::init()
     // TopLayout--TextLabel
     titleLabel = new QLabel;
     titleLabel->setObjectName("TitleLabel");
+    titleLabel->setAccessibleName("DDialogTitleLabel");
     titleLabel->setAttribute(Qt::WA_TransparentForMouseEvents);
     titleLabel->setWordWrap(true);
     titleLabel->setAlignment(Qt::AlignCenter);
-    titleLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
+    titleLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    titleLabel->installEventFilter(q);
     DFontSizeManager *fontManager =  DFontSizeManager::instance();
     fontManager->bind(titleLabel, DFontSizeManager::T5, QFont::Medium);
     palrtteTransparency(titleLabel, -10);
@@ -81,10 +83,12 @@ void DDialogPrivate::init()
     messageLabel = new QLabel;
     fontManager->bind(messageLabel, DFontSizeManager::T6, QFont::Medium);
     messageLabel->setObjectName("MessageLabel");
+    messageLabel->setAccessibleName("DDialogMessageLabel");
     messageLabel->setAttribute(Qt::WA_TransparentForMouseEvents);
     messageLabel->setWordWrap(true);
     messageLabel->setAlignment(Qt::AlignCenter);
     messageLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    messageLabel->installEventFilter(q);
     palrtteTransparency(messageLabel, -30);
     messageLabel->hide();
 
@@ -101,6 +105,7 @@ void DDialogPrivate::init()
     contentLayout->addLayout(textLayout);
 
     titleBar = new DTitlebar();
+    titleBar->setAccessibleName("DDialogTitleBar");
     titleBar->setIcon(icon); //设置标题icon
     titleBar->setMenuVisible(false);
     titleBar->setBackgroundTransparent(true);
@@ -112,7 +117,7 @@ void DDialogPrivate::init()
     spacer = new QSpacerItem(1, 0);
 
     // MainLayout--TopLayout
-    mainLayout->addWidget(titleBar);
+    mainLayout->addWidget(titleBar, 0, Qt::AlignTop);
     mainLayout->addLayout(contentLayout);
     mainLayout->setContentsMargins(QMargins(0, 0, 0, 0));
 
@@ -554,6 +559,7 @@ void DDialog::insertButton(int index, const QString &text, bool isDefault, Butto
 
     button->setText(text);
     button->setObjectName("ActionButton");
+    button->setAccessibleName(text);
     button->setAttribute(Qt::WA_NoMousePropagation);
 
     insertButton(index, button, isDefault);
@@ -1110,6 +1116,27 @@ void DDialog::keyPressEvent(QKeyEvent *event)
     }
 }
 
+bool DDialog::eventFilter(QObject *watched, QEvent *event)
+{
+    Q_D(DDialog);
+
+    if (watched == d->messageLabel || watched == d->titleLabel) {
+        if (event->type() == QEvent::FontChange) {
+            QLabel *label = qobject_cast<QLabel *>(watched);
+
+            if (label && !label->text().isEmpty() && label->wordWrap()) {
+                QSize sz = style()->itemTextRect(label->fontMetrics(), label->rect(), Qt::TextWordWrap, false, label->text()).size();
+
+                label->setMinimumHeight(qMax(sz.height(), label->height()));
+            }
+        }
+
+        return false;
+    }
+
+    return DAbstractDialog::eventFilter(watched, event);
+}
+
 DWIDGET_END_NAMESPACE
 
 #include "moc_ddialog.cpp"
