@@ -14,6 +14,7 @@
 #include "dfiledialog.h"
 #include "dapplicationhelper.h"
 #include "dstyleoption.h"
+#include "dapplication.h"
 
 #include <DScrollArea>
 
@@ -35,12 +36,8 @@
 #include <qpa/qplatformprintplugin.h>
 #include <qpa/qplatformprintersupport.h>
 
-#include <cups/ppd.h>
-#include <cups/cups.h>
-
 #define NORMAL_LEFT_RIGHT 31.8
 #define NORMAL_MODERATE_TOP_BOTTRM 25.4
-#define NARROW_ALL 12.7
 #define MODERATE_LEFT_RIGHT 19.1
 
 #define EightK_Weight 270
@@ -79,8 +76,6 @@ void DPrintPreviewDialogPrivate::startup()
     Q_Q(DPrintPreviewDialog);
 
     this->printer = new DPrinter;
-    this->marginTimer = new QTimer(q);
-    this->marginTimer->setSingleShot(true);
 
     initui();
     initdata();
@@ -91,10 +86,9 @@ void DPrintPreviewDialogPrivate::initui()
 {
     Q_Q(DPrintPreviewDialog);
     DWidget *mainWidget = new DWidget(q);
-    mainWidget->setGeometry(0, 0, q->width(), q->height());
+    mainWidget->setObjectName("mainwidget");
 
     DWidget *titleWidget = new DWidget(q);
-    titleWidget->setGeometry(0, 0, q->width(), 50);
     titleWidget->setObjectName("titlewidget");
 
     mainWidget->setAutoFillBackground(true);
@@ -109,7 +103,6 @@ void DPrintPreviewDialogPrivate::initui()
     mainlayout->setSpacing(0);
     DFrame *pframe = new DFrame;
     pframe->setLayout(mainlayout);
-    pframe->setFixedHeight(536);
     pframe->setLineWidth(0);
 
     QVBoxLayout *pleftlayout = new QVBoxLayout;
@@ -186,7 +179,7 @@ void DPrintPreviewDialogPrivate::initright(QVBoxLayout *layout)
     scrollarea->setFrameShape(QFrame::NoFrame);
     scrollarea->hide();
 
-    advanceBtn = new DPushButton(q->tr("Advanced"));
+    advanceBtn = new DPushButton(qApp->translate("DPrintPreviewDialogPrivate", "Advanced"));
     advanceBtn->setLayoutDirection(Qt::RightToLeft);
     advanceBtn->setIcon(QIcon::fromTheme("printer_dropdown"));
     advanceBtn->setIconSize(QSize(12, 12));
@@ -208,8 +201,8 @@ void DPrintPreviewDialogPrivate::initright(QVBoxLayout *layout)
     //bottom
     QHBoxLayout *pbottomlayout = new QHBoxLayout;
     pbottomlayout->setContentsMargins(0, 10, 0, 10);
-    cancelBtn = new DPushButton(q->tr("Cancel"));
-    printBtn = new DSuggestButton(q->tr("Print"));
+    cancelBtn = new DPushButton(qApp->translate("DPrintPreviewDialogPrivate", "Cancel"));
+    printBtn = new DSuggestButton(qApp->translate("DPrintPreviewDialogPrivate", "Print"));
 
     cancelBtn->setFixedSize(170, 36);
     printBtn->setFixedSize(170, 36);
@@ -225,7 +218,7 @@ void DPrintPreviewDialogPrivate::initbasicui()
     Q_Q(DPrintPreviewDialog);
     QVBoxLayout *layout = new QVBoxLayout(basicsettingwdg);
     layout->setSpacing(10);
-    DLabel *basicLabel = new DLabel(q->tr("Basic"), basicsettingwdg);
+    DLabel *basicLabel = new DLabel(qApp->translate("DPrintPreviewDialogPrivate", "Basic"), basicsettingwdg);
     setwidgetfont(basicLabel);
     QHBoxLayout *basictitlelayout = new QHBoxLayout;
     layout->addLayout(basictitlelayout);
@@ -240,7 +233,7 @@ void DPrintPreviewDialogPrivate::initbasicui()
     setfrmaeback(printerFrame);
     QHBoxLayout *printerlayout = new QHBoxLayout(printerFrame);
     printerlayout->setContentsMargins(10, 0, 10, 0);
-    DLabel *printerlabel = new DLabel(q->tr("Printer"), printerFrame);
+    DLabel *printerlabel = new DLabel(qApp->translate("DPrintPreviewDialogPrivate", "Printer"), printerFrame);
     printDeviceCombo = new DComboBox(basicsettingwdg);
     printDeviceCombo->setFixedSize(275, 36);
     printerlayout->addWidget(printerlabel);
@@ -255,7 +248,7 @@ void DPrintPreviewDialogPrivate::initbasicui()
     setfrmaeback(copycountFrame);
     QHBoxLayout *copycountlayout = new QHBoxLayout(copycountFrame);
     copycountlayout->setContentsMargins(10, 0, 10, 0);
-    DLabel *copycountlabel = new DLabel(q->tr("Copies"), copycountFrame);
+    DLabel *copycountlabel = new DLabel(qApp->translate("DPrintPreviewDialogPrivate", "Copies"), copycountFrame);
     copycountspinbox = new DSpinBox(copycountFrame);
     copycountspinbox->setEnabledEmbedStyle(true);
     copycountspinbox->setRange(1, 999);
@@ -275,12 +268,12 @@ void DPrintPreviewDialogPrivate::initbasicui()
     setfrmaeback(pageFrame);
     QVBoxLayout *pagelayout = new QVBoxLayout(pageFrame);
     pagelayout->setContentsMargins(10, 5, 10, 5);
-    DLabel *pagerangelabel = new DLabel(q->tr("Page range"), pageFrame);
+    DLabel *pagerangelabel = new DLabel(qApp->translate("DPrintPreviewDialogPrivate", "Page range"), pageFrame);
     pageRangeCombo = new DComboBox(pageFrame);
     pageRangeCombo->setFixedSize(275, 36);
-    pageRangeCombo->addItem(q->tr("All"));
-    pageRangeCombo->addItem(q->tr("Current page"));
-    pageRangeCombo->addItem(q->tr("Select pages"));
+    pageRangeCombo->addItem(qApp->translate("DPrintPreviewDialogPrivate", "All"));
+    pageRangeCombo->addItem(qApp->translate("DPrintPreviewDialogPrivate", "Current page"));
+    pageRangeCombo->addItem(qApp->translate("DPrintPreviewDialogPrivate", "Select pages"));
     QHBoxLayout *hrangebox = new QHBoxLayout();
     hrangebox->addWidget(pagerangelabel);
     hrangebox->addWidget(pageRangeCombo);
@@ -295,7 +288,7 @@ void DPrintPreviewDialogPrivate::initbasicui()
     pageRangeEdit->lineEdit()->setValidator(val);
 
     //打印方向
-    DLabel *orientationLabel = new DLabel(q->tr("Orientation"), basicsettingwdg);
+    DLabel *orientationLabel = new DLabel(qApp->translate("DPrintPreviewDialogPrivate", "Orientation"), basicsettingwdg);
     setwidgetfont(orientationLabel);
     QHBoxLayout *orientationtitlelayout = new QHBoxLayout;
     orientationtitlelayout->setContentsMargins(10, 0, 0, 0);
@@ -319,7 +312,7 @@ void DPrintPreviewDialogPrivate::initbasicui()
     DWidget *portraitwdg = new DWidget;
     portraitwdg->setFixedSize(422, 48);
     QHBoxLayout *portraitlayout = new QHBoxLayout;
-    DLabel *orientationTextLabel = new DLabel(q->tr("Portrait"), portraitwdg);
+    DLabel *orientationTextLabel = new DLabel(qApp->translate("DPrintPreviewDialogPrivate", "Portrait"), portraitwdg);
     portraitlayout->addWidget(verRadio);
     portraitlayout->addWidget(orientationTextLabel);
     portraitlayout->addStretch();
@@ -329,7 +322,7 @@ void DPrintPreviewDialogPrivate::initbasicui()
     DWidget *landscapewdg = new DWidget;
     landscapewdg->setFixedSize(422, 48);
     QHBoxLayout *landscapelayout = new QHBoxLayout;
-    DLabel *landscapeTextLabel = new DLabel(q->tr("Landscape"), portraitwdg);
+    DLabel *landscapeTextLabel = new DLabel(qApp->translate("DPrintPreviewDialogPrivate", "Landscape"), portraitwdg);
     landscapelayout->addWidget(horRadio);
     landscapelayout->addWidget(landscapeTextLabel);
     landscapelayout->addStretch();
@@ -356,7 +349,7 @@ void DPrintPreviewDialogPrivate::initadvanceui()
     QVBoxLayout *pagelayout = new QVBoxLayout;
     pagelayout->setSpacing(10);
     pagelayout->setContentsMargins(10, 0, 10, 0);
-    DLabel *pagesLabel = new DLabel(q->tr("Pages"), advancesettingwdg);
+    DLabel *pagesLabel = new DLabel(qApp->translate("DPrintPreviewDialogPrivate", "Pages"), advancesettingwdg);
     setwidgetfont(pagesLabel, DFontSizeManager::T5);
     QHBoxLayout *pagestitlelayout = new QHBoxLayout;
     pagestitlelayout->setContentsMargins(10, 20, 0, 0);
@@ -366,10 +359,10 @@ void DPrintPreviewDialogPrivate::initadvanceui()
     setfrmaeback(colorframe);
     colorframe->setFixedHeight(48);
     QHBoxLayout *colorlayout = new QHBoxLayout(colorframe);
-    DLabel *colorlabel = new DLabel(q->tr("Color mode"));
+    DLabel *colorlabel = new DLabel(qApp->translate("DPrintPreviewDialogPrivate", "Color mode"));
     colorlabel->setFixedWidth(123);
     colorModeCombo = new DComboBox;
-    colorModeCombo->addItems(QStringList() << q->tr("Color") << q->tr("Grayscale"));
+    colorModeCombo->addItems(QStringList() << qApp->translate("DPrintPreviewDialogPrivate", "Color") << qApp->translate("DPrintPreviewDialogPrivate", "Grayscale"));
     colorlayout->addWidget(colorlabel);
     colorlayout->addWidget(colorModeCombo);
     colorlayout->setContentsMargins(10, 4, 10, 4);
@@ -380,25 +373,25 @@ void DPrintPreviewDialogPrivate::initadvanceui()
     QVBoxLayout *marginslayout = new QVBoxLayout(marginsframe);
     marginslayout->setContentsMargins(10, 5, 10, 5);
     QHBoxLayout *marginscombolayout = new QHBoxLayout;
-    DLabel *marginlabel = new DLabel(q->tr("Margins"));
+    DLabel *marginlabel = new DLabel(qApp->translate("DPrintPreviewDialogPrivate", "Margins"));
     marginlabel->setFixedSize(123, 36);
     marginsCombo = new DComboBox;
-    marginsCombo->addItems(QStringList() << q->tr("Normal(mm)") << q->tr("Narrow(mm)") << q->tr("Moderate(mm)") << q->tr("Customize(mm)"));
+    marginsCombo->addItems(QStringList() << qApp->translate("DPrintPreviewDialogPrivate", "Narrow(mm)") << qApp->translate("DPrintPreviewDialogPrivate", "Normal(mm)") << qApp->translate("DPrintPreviewDialogPrivate", "Moderate(mm)") << qApp->translate("DPrintPreviewDialogPrivate", "Customize(mm)"));
     marginscombolayout->addWidget(marginlabel);
     marginscombolayout->addWidget(marginsCombo);
 
     QHBoxLayout *marginsspinlayout = new QHBoxLayout;
     marginsspinlayout->setContentsMargins(0, 0, 0, 0);
-    DLabel *toplabel = new DLabel(q->tr("Top"));
+    DLabel *toplabel = new DLabel(qApp->translate("DPrintPreviewDialogPrivate", "Top"));
     marginTopSpin = new DDoubleSpinBox;
     marginTopSpin->installEventFilter(q);
-    DLabel *leftlabel = new DLabel(q->tr("Left"));
+    DLabel *leftlabel = new DLabel(qApp->translate("DPrintPreviewDialogPrivate", "Left"));
     marginLeftSpin = new DDoubleSpinBox;
     marginLeftSpin->installEventFilter(q);
-    DLabel *bottomlabel = new DLabel(q->tr("Bottom"));
+    DLabel *bottomlabel = new DLabel(qApp->translate("DPrintPreviewDialogPrivate", "Bottom"));
     marginBottomSpin = new DDoubleSpinBox;
     marginBottomSpin->installEventFilter(q);
-    DLabel *rightlabel = new DLabel(q->tr("Right"));
+    DLabel *rightlabel = new DLabel(qApp->translate("DPrintPreviewDialogPrivate", "Right"));
     marginRightSpin = new DDoubleSpinBox;
     marginRightSpin->installEventFilter(q);
     QVBoxLayout *marginslabellayout1 = new QVBoxLayout;
@@ -440,7 +433,7 @@ void DPrintPreviewDialogPrivate::initadvanceui()
     //缩放
     QVBoxLayout *scalinglayout = new QVBoxLayout;
     scalinglayout->setContentsMargins(10, 0, 10, 0);
-    DLabel *scalingLabel = new DLabel(q->tr("Scaling"), advancesettingwdg);
+    DLabel *scalingLabel = new DLabel(qApp->translate("DPrintPreviewDialogPrivate", "Scaling"), advancesettingwdg);
     QHBoxLayout *scalingtitlelayout = new QHBoxLayout;
     scalingtitlelayout->setContentsMargins(10, 20, 0, 0);
     scalingtitlelayout->addWidget(scalingLabel, Qt::AlignLeft | Qt::AlignBottom);
@@ -454,7 +447,7 @@ void DPrintPreviewDialogPrivate::initadvanceui()
     actualwdg->setFixedHeight(48);
     QHBoxLayout *actuallayout = new QHBoxLayout(actualwdg);
     actuallayout->setContentsMargins(10, 0, 10, 0);
-    DRadioButton *actualSizeRadio = new DRadioButton(q->tr("Actual size"));
+    DRadioButton *actualSizeRadio = new DRadioButton(qApp->translate("DPrintPreviewDialogPrivate", "Actual size"));
 
     scaleGroup->addButton(actualSizeRadio, ACTUAL_SIZE);
     actuallayout->addWidget(actualSizeRadio);
@@ -463,7 +456,7 @@ void DPrintPreviewDialogPrivate::initadvanceui()
     customscalewdg->setFixedHeight(48);
     QHBoxLayout *customlayout = new QHBoxLayout(customscalewdg);
     customlayout->setContentsMargins(10, 0, 10, 0);
-    DRadioButton *customSizeRadio = new DRadioButton(q->tr("Scale"));
+    DRadioButton *customSizeRadio = new DRadioButton(qApp->translate("DPrintPreviewDialogPrivate", "Scale"));
     scaleGroup->addButton(customSizeRadio, SCALE);
     scaleRateEdit = new DSpinBox;
     QRegExp scaleReg("^([1-9][0-9]?|[1][0-9]{2}|200)$");
@@ -493,7 +486,7 @@ void DPrintPreviewDialogPrivate::initadvanceui()
     //纸张
     QVBoxLayout *paperlayout = new QVBoxLayout;
     paperlayout->setContentsMargins(10, 0, 10, 0);
-    DLabel *paperLabel = new DLabel(q->tr("Paper"), advancesettingwdg);
+    DLabel *paperLabel = new DLabel(qApp->translate("DPrintPreviewDialogPrivate", "Paper"), advancesettingwdg);
     setwidgetfont(paperLabel, DFontSizeManager::T5);
     QHBoxLayout *papertitlelayout = new QHBoxLayout;
     papertitlelayout->setContentsMargins(10, 0, 0, 0);
@@ -503,7 +496,7 @@ void DPrintPreviewDialogPrivate::initadvanceui()
     setfrmaeback(paperframe);
     paperframe->setFixedHeight(48);
     QHBoxLayout *paperframelayout = new QHBoxLayout(paperframe);
-    DLabel *papersizelabel = new DLabel(q->tr("Paper size"));
+    DLabel *papersizelabel = new DLabel(qApp->translate("DPrintPreviewDialogPrivate", "Paper size"));
     papersizelabel->setFixedWidth(123);
     paperSizeCombo = new DComboBox;
     paperSizeCombo->setFixedHeight(36);
@@ -517,7 +510,7 @@ void DPrintPreviewDialogPrivate::initadvanceui()
     QVBoxLayout *drawinglayout = new QVBoxLayout;
     drawinglayout->setSpacing(10);
     drawinglayout->setContentsMargins(10, 0, 10, 0);
-    DLabel *drawingLabel = new DLabel(q->tr("Layout"), advancesettingwdg);
+    DLabel *drawingLabel = new DLabel(qApp->translate("DPrintPreviewDialogPrivate", "Layout"), advancesettingwdg);
     setwidgetfont(drawingLabel, DFontSizeManager::T5);
     QHBoxLayout *drawingtitlelayout = new QHBoxLayout;
     drawingtitlelayout->setContentsMargins(10, 20, 0, 0);
@@ -528,7 +521,7 @@ void DPrintPreviewDialogPrivate::initadvanceui()
     duplexframe->setFixedHeight(48);
     QHBoxLayout *duplexlayout = new QHBoxLayout(duplexframe);
     duplexCombo = new DComboBox;
-    duplexCheckBox = new DCheckBox(q->tr("Duplex"));
+    duplexCheckBox = new DCheckBox(qApp->translate("DPrintPreviewDialogPrivate", "Duplex"));
     duplexCheckBox->setFixedWidth(123);
     duplexCombo->setFixedHeight(36);
     duplexlayout->setContentsMargins(14, 4, 10, 4);
@@ -563,7 +556,7 @@ void DPrintPreviewDialogPrivate::initdata()
 {
     Q_Q(DPrintPreviewDialog);
     QStringList itemlist;
-    itemlist << QPrinterInfo::availablePrinterNames() << q->tr("Print to PDF");
+    itemlist << QPrinterInfo::availablePrinterNames() << qApp->translate("DPrintPreviewDialogPrivate", "Print to PDF");
     printDeviceCombo->addItems(itemlist);
     QString defauledevice = QPrinterInfo::defaultPrinterName();
     for (int i = 0; i < itemlist.size(); ++i) {
@@ -600,7 +593,6 @@ void DPrintPreviewDialogPrivate::initconnections()
     QObject::connect(printBtn, SIGNAL(clicked(bool)), q, SLOT(_q_startPrint(bool)));
     QObject::connect(colorModeCombo, SIGNAL(currentIndexChanged(int)), q, SLOT(_q_ColorModeChange(int)));
     QObject::connect(orientationgroup, SIGNAL(buttonClicked(int)), q, SLOT(_q_orientationChanged(int)));
-    QObject::connect(jumpPageEdit, SIGNAL(valueChanged(int)), q, SLOT(_q_currentPageSpinChanged(int)));
     QObject::connect(jumpPageEdit->lineEdit(), &QLineEdit::textChanged, q, [ = ](QString str) {
         if (str.toInt() > totalPageLabel->text().toInt())
             jumpPageEdit->lineEdit()->setText(totalPageLabel->text());
@@ -616,6 +608,8 @@ void DPrintPreviewDialogPrivate::initconnections()
     QObject::connect(pview, &DPrintPreviewWidget::pagesCountChanged, [this](int pages) {
         totalPageLabel->setNum(pages);
         setTurnPageBtnStatus();
+        if (!pages)
+            pview->setPageRangeALL();
     });
     QObject::connect(firstBtn, &DIconButton::clicked, pview, &DPrintPreviewWidget::turnBegin);
     QObject::connect(prevPageBtn, &DIconButton::clicked, pview, &DPrintPreviewWidget::turnFront);
@@ -670,13 +664,18 @@ void DPrintPreviewDialogPrivate::initconnections()
             if (marginsCombo->currentIndex() == 3) {
                 setMininumMargins();
                 printer->setPageMargins(printer->pageLayout().minimumMargins(), QPageLayout::Millimeter);
-                if (marginTimer->isActive())
-                    marginTimer->stop();
+                pview->updatePreview();
+            } else if (marginsCombo->currentIndex() == 0) {
+                if (!marginsControl)
+                    _q_pageMarginChanged(0);
+                marginsControl = false;
+            } else {
+                pview->updatePreview();
             }
-            pview->updatePreview();
         }
-        if (pview->pageRangeMode() != DPrintPreviewWidget::AllPage)
+        if (pview->pageRangeMode() != DPrintPreviewWidget::AllPage) {
             _q_customPagesFinished();
+        }
     });
 
     QObject::connect(scaleRateEdit->lineEdit(), &QLineEdit::editingFinished, q, [=] {
@@ -687,8 +686,9 @@ void DPrintPreviewDialogPrivate::initconnections()
             pview->setScale(scale);
             pview->updateView();
 
-            if (pview->pageRangeMode() != DPrintPreviewWidget::AllPage)
+            if (pview->pageRangeMode() != DPrintPreviewWidget::AllPage) {
                 _q_customPagesFinished();
+            }
         }
     });
     QObject::connect(scaleGroup, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), q, [this](int id) {
@@ -702,25 +702,17 @@ void DPrintPreviewDialogPrivate::initconnections()
         }
         pview->updateView();
 
-        if (pview->pageRangeMode() != DPrintPreviewWidget::AllPage)
+        if (pview->pageRangeMode() != DPrintPreviewWidget::AllPage) {
             _q_customPagesFinished();
+        }
     });
 
-    QObject::connect(marginTimer, SIGNAL(timeout()), q, SLOT(_q_marginTimerOut()));
-    QObject::connect(marginTopSpin, SIGNAL(valueChanged(double)), q, SLOT(_q_marginspinChanged(double)));
-    QObject::connect(marginRightSpin, SIGNAL(valueChanged(double)), q, SLOT(_q_marginspinChanged(double)));
-    QObject::connect(marginLeftSpin, SIGNAL(valueChanged(double)), q, SLOT(_q_marginspinChanged(double)));
-    QObject::connect(marginBottomSpin, SIGNAL(valueChanged(double)), q, SLOT(_q_marginspinChanged(double)));
     QObject::connect(duplexCheckBox, SIGNAL(stateChanged(int)), q, SLOT(_q_checkStateChanged(int)));
     QObject::connect(DApplicationHelper::instance(), &DApplicationHelper::themeTypeChanged, pview, &DPrintPreviewWidget::themeTypeChanged);
     QObject::connect(marginTopSpin, SIGNAL(editingFinished()), q, SLOT(_q_marginEditFinished()));
     QObject::connect(marginRightSpin, SIGNAL(editingFinished()), q, SLOT(_q_marginEditFinished()));
     QObject::connect(marginLeftSpin, SIGNAL(editingFinished()), q, SLOT(_q_marginEditFinished()));
     QObject::connect(marginBottomSpin, SIGNAL(editingFinished()), q, SLOT(_q_marginEditFinished()));
-    QObject::connect(scaleRateEdit, QOverload<int>::of(&DSpinBox::valueChanged), q, [=] {
-        // 使用和margin相同的定时器，定时1秒钟
-        marginTimer->start(1000);
-    });
     QObject::connect(DApplicationHelper::instance(), &DApplicationHelper::themeTypeChanged, q, [this](DGuiApplicationHelper::ColorType themeType) { this->themeTypeChange(themeType); });
 }
 
@@ -836,6 +828,8 @@ void DPrintPreviewDialogPrivate::judgeSupportedAttributes(const QString &lastPap
     } else {
         //调用绘制预览
         paperSizeCombo->blockSignals(false);
+        if (isInited)
+            marginsControl = true;
         paperSizeCombo->setCurrentText("A4");
     }
 
@@ -845,14 +839,14 @@ void DPrintPreviewDialogPrivate::judgeSupportedAttributes(const QString &lastPap
     if (updateinfo.supportedDuplexModes().contains(QPrinter::DuplexLongSide) || updateinfo.supportedDuplexModes().contains(QPrinter::DuplexShortSide)) {
         duplexCheckBox->setEnabled(true);
         if (!updateinfo.supportedDuplexModes().contains(QPrinter::DuplexLongSide)) {
-            duplexCombo->addItem(q->tr("Flip on short edge"));
+            duplexCombo->addItem(qApp->translate("DPrintPreviewDialogPrivate", "Flip on short edge"));
             supportedDuplexFlag = false;
         } else if (!updateinfo.supportedDuplexModes().contains(QPrinter::DuplexShortSide)) {
-            duplexCombo->addItem(q->tr("Flip on long edge"));
+            duplexCombo->addItem(qApp->translate("DPrintPreviewDialogPrivate", "Flip on long edge"));
             supportedDuplexFlag = true;
         } else if (updateinfo.supportedDuplexModes().contains(QPrinter::DuplexLongSide) && updateinfo.supportedDuplexModes().contains(QPrinter::DuplexShortSide)) {
-            duplexCombo->addItem(q->tr("Flip on long edge"));
-            duplexCombo->addItem(q->tr("Flip on short edge"));
+            duplexCombo->addItem(qApp->translate("DPrintPreviewDialogPrivate", "Flip on long edge"));
+            duplexCombo->addItem(qApp->translate("DPrintPreviewDialogPrivate", "Flip on short edge"));
             duplexCombo->setCurrentText(lastDuplexComboText);
         }
     } else {
@@ -905,12 +899,16 @@ void DPrintPreviewDialogPrivate::themeTypeChange(DGuiApplicationHelper::ColorTyp
 }
 
 /*!
- * \~chinese DPrintPreviewDialogPrivate::setWaringPage 当自定义页码不合理,设置警告颜色
+ * \~chinese DPrintPreviewDialogPrivate::setPageIsLegal 检查自定义页码是否合法,不合法的话设置警告颜色,打印保存按钮置灰
  */
-void DPrintPreviewDialogPrivate::setWaringPage()
+void DPrintPreviewDialogPrivate::setPageIsLegal(bool islegal)
 {
-    pageRangeEdit->setAlert(true);
-    pview->setCurrentPage(1);
+    printBtn->setEnabled(islegal);
+    pageRangeEdit->setAlert(!islegal);
+    if (!islegal) {
+        pview->setPageRange(FIRST_PAGE, totalPages);
+        pview->setCurrentPage(1);
+    }
 }
 
 QVector<int> DPrintPreviewDialogPrivate::checkDuplication(QVector<int> data)
@@ -1015,12 +1013,12 @@ void DPrintPreviewDialogPrivate::_q_printerChanged(int index)
         duplexCombo->clear();
         duplexCombo->setEnabled(false);
         if (colorModeCombo->count() == 1)
-            colorModeCombo->insertItem(0, q->tr("Color"));
+            colorModeCombo->insertItem(0, qApp->translate("DPrintPreviewDialogPrivate", "Color"));
         colorModeCombo->blockSignals(false);
         colorModeCombo->setCurrentIndex(0);
         colorModeCombo->setEnabled(false);
         supportedColorMode = true;
-        printBtn->setText(q->tr("Save"));
+        printBtn->setText(qApp->translate("DPrintPreviewDialogPrivate", "Save"));
         paperSizeCombo->setCurrentIndex(1);
         QStringList pdfPaperSize = QStringList() << "A3"
                                                  << "A4"
@@ -1035,6 +1033,8 @@ void DPrintPreviewDialogPrivate::_q_printerChanged(int index)
         else {
             //调用绘制预览
             paperSizeCombo->blockSignals(false);
+            if (isInited)
+                marginsControl = true;
             paperSizeCombo->setCurrentIndex(1);
         }
         printer->setPrinterName("");
@@ -1045,7 +1045,7 @@ void DPrintPreviewDialogPrivate::_q_printerChanged(int index)
             paperSizeCombo->setEnabled(true);
             colorModeCombo->setEnabled(true);
             printer->setPrinterName(printDeviceCombo->itemText(index));
-            printBtn->setText(q->tr("Print"));
+            printBtn->setText(qApp->translate("DPrintPreviewDialogPrivate", "Print"));
             judgeSupportedAttributes(lastPaperSize);
         }
         //判断当前打印机是否支持彩色打印，不支持彩色打印删除彩色打印选择选项，pdf不做判断
@@ -1054,10 +1054,10 @@ void DPrintPreviewDialogPrivate::_q_printerChanged(int index)
         colorModeCombo->clear();
         if (!currentDevice.supportedColorModes().contains(QPrint::Color)) {
             colorModeCombo->blockSignals(false);
-            colorModeCombo->addItem(q->tr("Grayscale"));
+            colorModeCombo->addItem(qApp->translate("DPrintPreviewDialogPrivate", "Grayscale"));
             supportedColorMode = false;
         } else {
-            colorModeCombo->addItems(QStringList() << q->tr("Color") << q->tr("Grayscale"));
+            colorModeCombo->addItems(QStringList() << qApp->translate("DPrintPreviewDialogPrivate", "Color") << qApp->translate("DPrintPreviewDialogPrivate", "Grayscale"));
             colorModeCombo->blockSignals(false);
             if (colorModeCombo->currentText() == lastColormode) {
                 colorModeCombo->setCurrentIndex(0);
@@ -1071,10 +1071,11 @@ void DPrintPreviewDialogPrivate::_q_printerChanged(int index)
     if (marginsCombo->currentIndex() == 3) {
         setMininumMargins();
         printer->setPageMargins(printer->pageLayout().minimumMargins(), QPageLayout::Millimeter);
-        if (marginTimer->isActive())
-            marginTimer->stop();
         pview->updatePreview();
+    } else if (marginsCombo->currentIndex() == 0) {
+        _q_pageMarginChanged(0);
     }
+
     _q_customPagesFinished();
     paperSizeCombo->blockSignals(false);
 }
@@ -1091,7 +1092,7 @@ void DPrintPreviewDialogPrivate::_q_pageRangeChanged(int index)
     pageRangeEdit->setText("");
     if (index == DPrintPreviewWidget::AllPage) {
         pview->setPageRangeMode(DPrintPreviewWidget::AllPage);
-        pageRangeEdit->setAlert(false);
+        setPageIsLegal(true);
         if (totalPages != 0) {
             totalPageLabel->setNum(totalPages);
             if (isInited)
@@ -1099,20 +1100,21 @@ void DPrintPreviewDialogPrivate::_q_pageRangeChanged(int index)
         }
     } else if (index == DPrintPreviewWidget::CurrentPage) {
         pview->setPageRangeMode(DPrintPreviewWidget::CurrentPage);
-        pageRangeEdit->setAlert(false);
+        setPageIsLegal(true);
         int currentPage = pview->currentPage();
         pview->setPageRange(currentPage, currentPage);
     } else {
         pview->setPageRangeMode(DPrintPreviewWidget::SelectPage);
         if (lastPageRange.isEmpty()) {
-            pageRangeEdit->lineEdit()->setPlaceholderText(q->tr("1-%1. For example, 1,3,5-7,11-15,18,21").arg(QString::number(totalPages)));
+            pageRangeEdit->lineEdit()->setPlaceholderText(qApp->translate("DPrintPreviewDialogPrivate", "1-%1. For example, 1,3,5-7,11-15,18,21").arg(QString::number(totalPages)));
+            setPageIsLegal(false);
             pview->setPageRange(FIRST_PAGE, totalPages);
         } else {
             pageRangeEdit->setText(lastPageRange);
             _q_customPagesFinished();
         }
     }
-    _q_currentPageSpinChanged(1);
+    setTurnPageBtnStatus();
 }
 
 /*!
@@ -1123,25 +1125,19 @@ void DPrintPreviewDialogPrivate::_q_pageMarginChanged(int index)
 {
     setEnable(index, marginsCombo);
     if (index == 1) {
-        if (marginTimer->isActive())
-            marginTimer->stop();
-
         marginLeftSpin->blockSignals(true);
         marginTopSpin->blockSignals(true);
         marginRightSpin->blockSignals(true);
         marginBottomSpin->blockSignals(true);
 
-        marginLeftSpin->setValue(NARROW_ALL);
-        marginTopSpin->setValue(NARROW_ALL);
-        marginRightSpin->setValue(NARROW_ALL);
-        marginBottomSpin->setValue(NARROW_ALL);
-        printer->setPageMargins(QMarginsF(NARROW_ALL, NARROW_ALL, NARROW_ALL, NARROW_ALL), QPageLayout::Millimeter);
+        marginTopSpin->setValue(NORMAL_MODERATE_TOP_BOTTRM);
+        marginLeftSpin->setValue(NORMAL_LEFT_RIGHT);
+        marginRightSpin->setValue(NORMAL_LEFT_RIGHT);
+        marginBottomSpin->setValue(NORMAL_MODERATE_TOP_BOTTRM);
+        printer->setPageMargins(QMarginsF(NORMAL_LEFT_RIGHT, NORMAL_MODERATE_TOP_BOTTRM, NORMAL_LEFT_RIGHT, NORMAL_MODERATE_TOP_BOTTRM), QPageLayout::Millimeter);
 
         pview->updatePreview();
     } else if (index == 2) {
-        if (marginTimer->isActive())
-            marginTimer->stop();
-
         marginLeftSpin->blockSignals(true);
         marginTopSpin->blockSignals(true);
         marginRightSpin->blockSignals(true);
@@ -1159,11 +1155,10 @@ void DPrintPreviewDialogPrivate::_q_pageMarginChanged(int index)
         marginTopSpin->blockSignals(true);
         marginRightSpin->blockSignals(true);
         marginBottomSpin->blockSignals(true);
-
-        marginTopSpin->setValue(NORMAL_MODERATE_TOP_BOTTRM);
-        marginLeftSpin->setValue(NORMAL_LEFT_RIGHT);
-        marginRightSpin->setValue(NORMAL_LEFT_RIGHT);
-        marginBottomSpin->setValue(NORMAL_MODERATE_TOP_BOTTRM);
+        marginTopSpin->setValue(printer->pageLayout().minimumMargins().top());
+        marginLeftSpin->setValue(printer->pageLayout().minimumMargins().left());
+        marginRightSpin->setValue(printer->pageLayout().minimumMargins().right());
+        marginBottomSpin->setValue(printer->pageLayout().minimumMargins().bottom());
         printer->setPageMargins(QMarginsF(marginLeftSpin->value(), marginTopSpin->value(), marginRightSpin->value(), marginBottomSpin->value()), QPageLayout::Millimeter);
 
         pview->updatePreview();
@@ -1173,28 +1168,25 @@ void DPrintPreviewDialogPrivate::_q_pageMarginChanged(int index)
         marginRightSpin->blockSignals(false);
         marginBottomSpin->blockSignals(false);
     } else {
-        if (marginTimer->isActive())
-            marginTimer->stop();
-
         marginLeftSpin->blockSignals(true);
         marginTopSpin->blockSignals(true);
         marginRightSpin->blockSignals(true);
         marginBottomSpin->blockSignals(true);
 
-        marginTopSpin->setValue(NORMAL_MODERATE_TOP_BOTTRM);
-        marginLeftSpin->setValue(NORMAL_LEFT_RIGHT);
-        marginRightSpin->setValue(NORMAL_LEFT_RIGHT);
-        marginBottomSpin->setValue(NORMAL_MODERATE_TOP_BOTTRM);
-
-        printer->setPageMargins(QMarginsF(NORMAL_LEFT_RIGHT, NORMAL_MODERATE_TOP_BOTTRM, NORMAL_LEFT_RIGHT, NORMAL_MODERATE_TOP_BOTTRM), QPageLayout::Millimeter);
+        printer->setPageMargins(printer->pageLayout().minimumMargins(), QPageLayout::Millimeter);
+        marginTopSpin->setValue(printer->pageLayout().minimumMargins().top());
+        marginLeftSpin->setValue(printer->pageLayout().minimumMargins().left());
+        marginRightSpin->setValue(printer->pageLayout().minimumMargins().right());
+        marginBottomSpin->setValue(printer->pageLayout().minimumMargins().bottom());
+        printer->setPageMargins(QMarginsF(printer->pageLayout().minimumMargins().left(), printer->pageLayout().minimumMargins().top(), printer->pageLayout().minimumMargins().right(), printer->pageLayout().minimumMargins().bottom()), QPageLayout::Millimeter);
         if (isInited) {
             pview->updatePreview();
         }
     }
 
-    if (pview->pageRangeMode() != DPrintPreviewWidget::AllPage)
+    if (pview->pageRangeMode() != DPrintPreviewWidget::AllPage) {
         _q_customPagesFinished();
-
+    }
     if (marginOldValue.length() > 4)
         marginOldValue.clear();
 
@@ -1243,6 +1235,9 @@ void DPrintPreviewDialogPrivate::_q_orientationChanged(int index)
         pview->setOrientation(DPrinter::Landscape);
         pview->setReGenerate(true);
     }
+    if (pview->pageRangeMode() != DPrintPreviewWidget::AllPage) {
+        _q_customPagesFinished();
+    }
 }
 
 void DPrintPreviewDialogPrivate::_q_customPagesFinished()
@@ -1250,8 +1245,10 @@ void DPrintPreviewDialogPrivate::_q_customPagesFinished()
     if (pageRangeCombo->currentIndex() != 2)
         return;
     QString cuspages = pageRangeEdit->text();
+    lastPageRange = cuspages;
     QVector<int> pagesrange;
     QStringList list = cuspages.split(",");
+    setPageIsLegal(true);
     for (int i = 0; i < list.size(); i++) {
         if (list.at(i).contains("-")) {
             QStringList list1 = list.at(i).split("-");
@@ -1260,30 +1257,26 @@ void DPrintPreviewDialogPrivate::_q_customPagesFinished()
                     if (page != 0 && page <= totalPages){
                         pagesrange.append(page);
                     }else {
-                        setWaringPage();
+                        setPageIsLegal(false);
                         return;
                     }
                 }
             } else {
-                setWaringPage();
+                setPageIsLegal(false);
                 return;
             }
         } else {
             if (list.at(i).toInt() != 0 && list.at(i).toInt() <= totalPages){
                 pagesrange.append(list.at(i).toInt());
             }else {
-                setWaringPage();
+                setPageIsLegal(false);
                 return;
             }
         }
     }
-
-    pageRangeEdit->setAlert(false);
     jumpPageEdit->setValue(1);
-    //jumpPageEdit->setValue(1);
     QVector<int> page = checkDuplication(pagesrange);
     pview->setPageRange(page);
-    lastPageRange = cuspages;
     //_q_currentPageSpinChanged(1);
 }
 
@@ -1293,8 +1286,6 @@ void DPrintPreviewDialogPrivate::_q_customPagesFinished()
  */
 void DPrintPreviewDialogPrivate::_q_marginTimerOut()
 {
-    // 调用一次缩放页面的刷新，因为margin和scaleRatio使用同一个定时器
-    Q_EMIT scaleRateEdit->lineEdit()->editingFinished();
 
     qreal leftMarginF = this->marginLeftSpin->value();
     qreal topMarginF = this->marginTopSpin->value();
@@ -1312,8 +1303,9 @@ void DPrintPreviewDialogPrivate::_q_marginTimerOut()
         this->printer->setPageMargins(QMarginsF(leftMarginF, topMarginF, rightMarginF, bottomMarginF), QPageLayout::Millimeter);
         this->pview->updatePreview();
     }
-    if (pview->pageRangeMode() != DPrintPreviewWidget::AllPage)
+    if (pview->pageRangeMode() != DPrintPreviewWidget::AllPage) {
         _q_customPagesFinished();
+    }
 }
 
 /*!
@@ -1322,11 +1314,7 @@ void DPrintPreviewDialogPrivate::_q_marginTimerOut()
  */
 void DPrintPreviewDialogPrivate::_q_marginspinChanged(double)
 {
-    if (marginTimer->isActive())
-        marginTimer->stop();
 
-    // 默认1秒的定时器，时间到了就刷新预览页面
-    marginTimer->start(1000);
 }
 
 /*!
@@ -1337,13 +1325,10 @@ void DPrintPreviewDialogPrivate::_q_marginEditFinished()
 {
     Q_Q(DPrintPreviewDialog);
     setMininumMargins();
-    if (!marginTimer->isActive())
-        return;
 
     if (q->focusWidget() == marginTopSpin || q->focusWidget() == marginLeftSpin
             || q->focusWidget() == marginBottomSpin || q->focusWidget() == marginRightSpin)
         return;
-    marginTimer->stop();
     _q_marginTimerOut();
 }
 
@@ -1396,33 +1381,39 @@ void DPrintPreviewDialogPrivate::_q_startPrint(bool clicked)
         setupPrinter();
     }
     if (printDeviceCombo->currentIndex() == printDeviceCombo->count() - 1) {
-        //设置pdf保存文本信息，可以外部通过setDocName设置，如果不做任何操作默认保存名称print.pdf
+        /*设置pdf保存文本信息，如果设置outputfilename优先设置,如果outputfilename为空,
+        外部通过setDocName设置，如果不做任何操作默认保存名称print.pdf*/
         QString desktopPath = QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
         desktopPath += QStringLiteral("/");
         if (printer == nullptr) {
             return;
         }
         if (printer->outputFileName().isEmpty()) {
-            if (printer->docName().isEmpty())
+            if (printer->docName().isEmpty()) {
                 desktopPath += QStringLiteral("print.pdf");
-            QFileInfo file(desktopPath);
-            QString path = desktopPath;
-            if (file.isFile()) {
-                int i = 1;
-                do {
-                    QString stres("(%1).pdf");
-                    path = desktopPath.remove(".pdf") + stres.arg(i);
-                    file.setFile(path);
-                    i++;
-                } while (file.isFile());
-                desktopPath = path;
             } else {
                 desktopPath += printer->docName();
             }
         } else {
             desktopPath = printer->outputFileName();
         }
-        QString str = DFileDialog::getSaveFileName(q, q->tr("Save as PDF"), desktopPath, q->tr("PDF file"));
+        if (desktopPath.right(4).compare(".pdf", Qt::CaseInsensitive)) {
+            desktopPath += ".pdf";
+        }
+        QFileInfo file(desktopPath);
+        QString path = desktopPath;
+        if (file.isFile()) {
+            int i = 1;
+            do {
+                QString stres("(%1).pdf");
+                path = desktopPath.remove(path.right(4)) + stres.arg(i);
+                file.setFile(path);
+                i++;
+            } while (file.isFile());
+            desktopPath = path;
+        }
+
+        QString str = DFileDialog::getSaveFileName(q, qApp->translate("DPrintPreviewDialogPrivate", "Save as PDF"), desktopPath, qApp->translate("DPrintPreviewDialogPrivate", "PDF file"));
         if (str.isEmpty())
             return;
         printer->setOutputFileName(str);
@@ -1485,5 +1476,12 @@ bool DPrintPreviewDialog::eventFilter(QObject *watched, QEvent *event)
 
     return DDialog::eventFilter(watched, event);
 }
+
+void DPrintPreviewDialog::resizeEvent(QResizeEvent *event)
+{
+    Q_UNUSED(event);
+    this->findChild<DWidget *>("titlewidget")->setGeometry(0, 0, this->width(), 50);
+    this->findChild<DWidget *>("mainwidget")->setGeometry(0, 0, this->width(), this->height());
+}
 DWIDGET_END_NAMESPACE
 #include "moc_dprintpreviewdialog.cpp"
