@@ -37,12 +37,14 @@
 #include <QHBoxLayout>
 #include <QEvent>
 #include <QAction>
-#include <QAudioInput>
 #include <QTimer>
-#include <QAudioDeviceInfo>
 #include <QCoreApplication>
 #include <QToolButton>
 #include <QDBusPendingCallWatcher>
+#ifndef DTK_NO_MULTIMEDIA
+#include <QAudioInput>
+#include <QAudioDeviceInfo>
+#endif
 
 DWIDGET_BEGIN_NAMESPACE
 DCORE_USE_NAMESPACE
@@ -241,8 +243,12 @@ void DSearchEdit::clearEdit()
 
 bool DSearchEdit::isVoiceInput() const
 {
+#ifndef DTK_NO_MULTIMEDIA
     D_DC(DSearchEdit);
     return d->voiceInput && d->voiceInput->state() == QAudio::ActiveState;
+#else
+    return false;
+#endif
 }
 
 void DSearchEdit::setPlaceholderText(const QString &text)
@@ -280,11 +286,13 @@ void DSearchEditPrivate::init()
     iconbtn->setFlat(true);
     iconbtn->setFocusPolicy(Qt::NoFocus);
     iconbtn->setAttribute(Qt::WA_TransparentForMouseEvents);
+    iconbtn->setAccessibleName("DSearchEditIconButton");
 
     placeHolder = qApp->translate("DSearchEdit", "Search");
 
     action = new QAction(q);
-    action->setIcon(DStyleHelper(q->style()).standardIcon(DStyle::SP_IndicatorSearch, nullptr));
+    action->setObjectName("_d_search_leftAction");
+    action->setIcon(QIcon::fromTheme("search_action"));
     q->lineEdit()->addAction(action, QLineEdit::LeadingPosition);
     action->setVisible(false);
     iconbtn->setIconSize(QSize(32, 32));
@@ -296,6 +304,7 @@ void DSearchEditPrivate::init()
 
     label->setPalette(pe);
     label->setText(placeHolder);
+    label->setAccessibleName("DSearchEditPlaceHolderLabel");
 
     q->setFocusPolicy(Qt::ClickFocus);
 
@@ -309,6 +318,7 @@ void DSearchEditPrivate::init()
 
     iconWidget = new QWidget;
     iconWidget->setObjectName("iconWidget");
+    iconWidget->setAccessibleName("DSearchEditIconWidget");
     QHBoxLayout *center_layout = new QHBoxLayout(iconWidget);
     center_layout->setMargin(0);
     center_layout->setSpacing(0);
@@ -388,7 +398,7 @@ void DSearchEditPrivate::_q_toEditMode(bool focus)
 
 void DSearchEditPrivate::_q_onVoiceActionTrigger(bool checked)
 {
-#ifdef ENABLE_AI
+#if (!defined DTK_NO_MULTIMEDIA) && (defined ENABLE_AI)
     if (checked) {
         voiceAction->setIcon(QIcon::fromTheme("button_voice_active"));
 
@@ -431,6 +441,8 @@ void DSearchEditPrivate::_q_onVoiceActionTrigger(bool checked)
             voiceInput = nullptr;
         }
     }
+#else
+    Q_UNUSED(checked)
 #endif
 }
 
